import pandas as pd
import numpy as np

def clean_dataframe(df):
    """Cleans a DataFrame by:
    - Replacing NaN values in integer columns with blank (empty string) and then replacing blanks with 0.
    - Replacing NaN values in float columns with 0.0.
    - Replacing NaN values in string columns with empty string.
    - Stripping leading/trailing whitespace from string columns.
    - Replacing spaces in column names with underscores and trimming them.
    """
    df = df.copy()  # Work on a copy to avoid SettingWithCopyWarning

    # Clean column names (replace spaces with underscores, and remove leading/trailing spaces)
    df.columns = [col.strip().replace(" ", "_") for col in df.columns]

    for col in df.columns:
        if pd.api.types.is_numeric_dtype(df[col]):
            # For integer columns: Replace NaN with empty string and then with 0
            if pd.api.types.is_integer_dtype(df[col]):
                df[col] = df[col].fillna('')  # Replace NaN with blank for INT columns
                df[col] = df[col].replace('', 0)  # Replace blank with 0
                df[col] = df[col].astype('Int64')  # Ensure it's of type Int64 (nullable integer)
            # For float columns: Replace NaN with 0.0
            elif pd.api.types.is_float_dtype(df[col]):
                df[col] = df[col].fillna(0.0)  # Replace NaN with 0.0 for FLOAT columns
        else:
            # For non-numeric columns, replace NaN with empty string and trim spaces
            df[col] = df[col].fillna('')
            df[col] = df[col].astype(str).str.strip()

    return df
